import BuildControls from '@/components/BuildControls/BuildControls';
import Burger from '@/components/Burger/Burger';
import { IngredientNames, IngredientPrices, Ingredients } from '@/interfaces/Ingredients';
import { useState } from 'react';

const BurgerBuilder = () => {
    const [totalPrice, setTotalPrice] = useState<number>(IngredientPrices.bread);
    const [ingredients, setIngredients] = useState<Ingredients>({
        salad: 0,
        cheese: 0,
        chicken: 0,
        meat: 0
    })

    const moreHandler = (ingKey: IngredientNames) => {
        const oldCount = ingredients[ingKey];
        const updatedCount = oldCount + 1;
        const updatedIngredients = { ...ingredients };
        updatedIngredients[ingKey] = updatedCount;
        setIngredients(updatedIngredients);

        const priceAddition = IngredientPrices[ingKey];
        const newPrice = totalPrice + priceAddition;
        setTotalPrice(newPrice);
    }

    const lessHandler = (ingKey: IngredientNames) => {
        const oldCount = ingredients[ingKey];
        if (oldCount <= 0) {
            return;
        }

        const updatedCount = oldCount - 1;
        const updatedIngredients = { ...ingredients };
        updatedIngredients[ingKey] = updatedCount;
        setIngredients(updatedIngredients);

        const priceAddition = IngredientPrices[ingKey];
        const newPrice = totalPrice - priceAddition;
        setTotalPrice(newPrice);
    }

    return (
        <>
            <Burger ingredients={ingredients}/>
            <BuildControls 
                ingredients={ingredients} 
                lessHandler={lessHandler}
                moreHandler={moreHandler}
                price={totalPrice}
            />
        </>
    )
}

export default BurgerBuilder;
